{% macro render_field(field) %}
  <div class="inline_form">
    {{ field.label }}
    {{ field(**kwargs)|safe }}
    {% if field.errors %}
      <ul class=errors>
      {% for error in field.errors %}
        <li>{{ error }}</li>
      {% endfor %}
      </ul>
    {% endif %}
  </div>
{% endmacro %}

{% macro render_field_plain(field) %}
  <div class="inline_form">
    {{ field(**kwargs)|safe }}
    {% if field.errors %}
      <ul class=errors>
      {% for error in field.errors %}
        <li>{{ error }}</li>
      {% endfor %}
      </ul>
    {% endif %}
  </div>
{% endmacro %}
