{% extends "base.html" %}

{% block heading %}
<div id="heading">
    <h1>{{ config["PROJECT_NAME"] }}</h1>
</div>
{% endblock %}

{% block footer %}
<a href="/">{{ config["PROJECT_NAME"] }}</a>
{% endblock %}
