#footer {
    text-align: center;
    font-family: arial, helvetica, sans;
    font-size: 0.7em;
}

#content {
    width: 800px;
    margin: 0px auto;
}

label.control-label {
    margin-right: 1em ;
}

.checkbox input[type="checkbox"] {
    margin-left: 0px;
}
