# -*- coding: utf-8 -*-
# Flask-Diamond (c) Ian Dennis Miller

__project__ = 'Flask-Diamond'
__version__ = '0.5.0'
__author__ = 'Ian Dennis Miller'
__email__ = 'iandennismiller@gmail.com'
__url__ = 'http://flask-diamond.readthedocs.org'
__copyright__ = 'Ian Dennis Miller'
